/*
 * ciscode.h $Revision: 1.5 $ $Date: 1996/07/24 15:27:27 $ (David Hinds)
 */

#ifndef _LINUX_CISCODE_H
#define _LINUX_CISCODE_H

/* Manufacturer ID codes */
#define MANFID_SUNDISK		0x0045
#define MANFID_INTEL		0x0089
#define MANFID_IBM		0x00a4
#define MANFID_3COM		0x0101
#define MANFID_MEGAHERTZ	0x0102
#define MANFID_SMC		0x0108
#define MANFID_ADAPTEC		0x012f
#define MANFID_QUATECH		0x0137
#define MANFID_OSITECH		0x0140
#define MANFID_LINKSYS		0x0143
#define MANFID_ATT		0xffff

/* Product ID codes */
#define PRODID_3COM_3C562		0x0562
#define PRODID_ADAPTEC_SCSI		0x0001
#define PRODID_ATT_KIT			0x0100
#define PRODID_IBM_HOME_AND_AWAY	0x002e
#define PRODID_INTEL_2PLUS		0x8422
#define PRODID_LINKSYS_PCMLM28		0xc0ab
#define PRODID_MEGAHERTZ_VARIOUS	0x0000
#define PRODID_MEGAHERTZ_EM3288		0x0006
#define PRODID_OSITECH_JACK_144		0x0001
#define PRODID_OSITECH_JACK_288		0x0002
#define PRODID_QUATECH_DUAL_RS232	0x0012
#define PRODID_SMC_ETHER		0x0105

#endif /* _LINUX_CISCODE_H */
